SignalingDataCompression class

Utility functions for data compression and validation

Constructors

SignalingDataCompression()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

compressData(dynamic data) Uint8List
Compress data using gzip format
decompressData(Uint8List compressedData) Uint8List
Decompress gzip data (if needed for reading)
decompressToString(Uint8List compressedData) String
Convert decompressed bytes to string
isGzipFormat(Uint8List data) bool
Validate if data is in gzip format