SignalingContract class
Dart binding for Signaling smart contract
- Available extensions
Constructors
- SignalingContract({required Web3Client client, required DeployedContract contract, Credentials? credentials, int? chainId})
Properties
- chainId → int?
-
final
- client → Web3Client
-
final
- contract → DeployedContract
-
final
- credentials → Credentials?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getSignal(
EthereumAddress offerer) → Future< List< Object?> > - getSignal - View function
-
getSignalCompressed(
EthereumAddress offerer) → Future< String> -
Available on SignalingContract, provided by the SignalingContractExtension extension
Get signal with automatic gzip decompression -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
owner(
) → Future< EthereumAddress> - owner - View function
-
renounceOwnership(
) → Future< String> - renounceOwnership - Transaction function
-
setSignal(
Uint8List compressedSignal) → Future< String> - setSignal - Transaction function
-
setSignalCompressed(
dynamic data) → Future< String> -
Available on SignalingContract, provided by the SignalingContractExtension extension
Set signal with automatic gzip compression -
toString(
) → String -
A string representation of this object.
inherited
-
transferOwnership(
EthereumAddress newOwner) → Future< String> - transferOwnership - Transaction function
-
watchSignalEmitted(
{EthereumAddress? senderFilter}) → Stream< FilterEvent> -
Available on SignalingContract, provided by the SignalingContractExtension extension
Listen to SignalEmitted events with optional sender filter
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
connect(
{required String rpcUrl, required EthereumAddress contractAddress, Credentials? credentials}) → Future< SignalingContract> - Factory constructor to connect to existing contract
-
connectWithClient(
{required Web3Client client, required EthereumAddress contractAddress, Credentials? credentials, int? chainId}) → Future< SignalingContract> - Connect to existing contract with pre-configured Web3Client
-
deploy(
{required String rpcUrl, required Credentials credentials, List< ContractParameter> constructorParams = const []}) → Future<SignalingContract> - Deploy new contract instance
Constants
- contractAbi → const String
- contractBytecode → const String